@@ -4,7 +4,12 @@ from .app import App
 # import pybi.core.styles as styles
 from pybi.core.styles import *
 from pybi.easyEcharts import *
+import pybi.icons.material_icons as md_icons
 
+md_icons = md_icons
+"""material icons小图标
+    >>> pbi.add_icon(pbi.md_icons.md_add_chart)
+"""
 
 app = App()
 
@@ -38,7 +43,8 @@ __all__ = [
     "add_mermaid",
     "add_input",
     "add_numberSlider",
-    "add_svg_icon",
+    # "add_svg_icon",
+    "md_icons",
 ]
 
 add_tabs = app.add_tabs
@@ -64,7 +70,7 @@ save_zip_db = app.save_zip_db
 to_html = app.to_html
 add_markdown = app.add_markdown
 add_icon = app.add_icon
-add_svg_icon = app.add_svg_icon
+# add_svg_icon = app.add_svg_icon
 affix = app.affix
 add_mermaid = app.add_mermaid
 add_input = app.add_input
