@@ -54,6 +54,8 @@ from pybi.core.components.reactiveComponent.echarts import (
     OptionsExtractor,
 )
 import pybi.utils.pyecharts_utils as pyecharts_utils
+from pybi.icons.iconManager import get_singleton as get_iconManager
+from pybi.core.webResources import WebResourceManager
 import pybi as pbi
 
 if TYPE_CHECKING:
@@ -99,6 +101,10 @@ class App(ContainerComponent):
         self.__meta = AppMeta(self)
         self.__json_utils = JsonUtils()
         self.__resourceManager = ResourceManager()
+        self._iconManager = get_iconManager()
+
+        self.__webResourceManager = WebResourceManager()
+        self.webResources = []
 
     def __record_and_check_dataset_name(self, name: str):
         if name in self.__dataSetNames:
@@ -176,7 +182,6 @@ class App(ContainerComponent):
         *,
         host: Optional[ContainerComponent] = None,
     ):
-
         cp = UploadComponent()
 
         host = host or self._get_temp_host() or self
@@ -238,7 +243,6 @@ class App(ContainerComponent):
         *,
         host: Optional[ContainerComponent] = None,
     ):
-
         sql = ""
         if dataSourceTable._user_specified_field:
             sql = dataSourceTable._to_sql()
@@ -286,7 +290,7 @@ class App(ContainerComponent):
                     chart._create_default_click_filter()
 
             for chart in opts._collector:
-                opts, updateInfos = chart.get_options_infos()
+                opts, updateInfos, mapIds = chart.get_options_infos()
 
                 ds_infos = []
                 jscodes = []
@@ -299,7 +303,10 @@ class App(ContainerComponent):
 
                 jscodes = [EChartJscode(path, jscode) for path, jscode in jscodes]
 
-                info = EChartInfo(opts, ds_infos, updateInfos, jscodes)
+                for map_name in mapIds:
+                    self.__webResourceManager.mark_echarts_map(map_name)
+
+                info = EChartInfo(opts, ds_infos, updateInfos, jscodes, mapIds)
                 cp._add_chart_info(info)
 
         elif isinstance(options, dict):
@@ -402,11 +409,50 @@ class App(ContainerComponent):
         ds2sqlite(path, self.dataSources)
 
     def _to_json_dict(self):
+        self.webResources.append(
+            {
+                "id": "DbFile",
+                "type": "DbFile",
+                "input": ds2sqlite_file_base64(
+                    self.dataSources, clear_data=self._clear_data
+                ),
+                "actionPipe": [],
+            }
+        )
+
+        # self.webResources.append(
+        #     {
+        #         "id": "maps1",
+        #         "type": "echarts-map",
+        #         "input": ds2sqlite_file_base64(
+        #             self.dataSources, clear_data=self._clear_data
+        #         ),
+        #         "actionPipe": [],
+        #     }
+        # )
+
+        # self.webResources.append(
+        #     {
+        #         "id": "maps1",
+        #         "type": "echarts-map",
+        #         "input": None,
+        #         "actionPipe": [
+        #             {
+        #                 "name": "fetch",
+        #                 "args": {
+        #                     "url": "https://geo.datav.aliyun.com/areas_v3/bound/100000_full.json",
+        #                     "options": {},
+        #                 },
+        #             }
+        #         ],
+        #     }
+        # )
+
+        wrs = self.__webResourceManager.create_webResources()
+        self.webResources.extend(wrs)
+
         data = super()._to_json_dict()
 
-        data["dbFile"] = ds2sqlite_file_base64(
-            self.dataSources, clear_data=self._clear_data
-        )
         if self._doc_title:
             data["docTitle"] = self._doc_title
 
@@ -444,7 +490,9 @@ class App(ContainerComponent):
             # file = Path(file)
             # raw = self.to_raw_html()
 
-            raw = self.__resourceManager.build_html(self.to_json())
+            raw = self.__resourceManager.build_html(
+                self.to_json(), svg_infos=get_iconManager().get_infos()
+            )
             Path(file).write_text(raw, "utf8")
 
             if display_output_path:
@@ -486,14 +534,14 @@ class App(ContainerComponent):
 
     def add_icon(
         self,
-        icon: str,
+        icon_svg: str,
         size="2em",
         color="currentColor",
         *,
         host: Optional[ContainerComponent] = None,
     ):
-
-        cp = IconComponent(icon, size, color)
+        icon_id = get_iconManager().make_icon(icon_svg)
+        cp = IconComponent(icon_id, size, color)
 
         host = host or self._get_temp_host() or self
         host._add_children(cp)
@@ -508,7 +556,6 @@ class App(ContainerComponent):
         *,
         host: Optional[ContainerComponent] = None,
     ):
-
         cp = SvgIconComponent(svg, size, color)
 
         host = host or self._get_temp_host() or self
