@@ -1,10 +1,18 @@
 from pybi.core.components.componentTag import ComponentTag
-from pybi.core.components.staticComponent import TextComponent, UploadComponent
+from pybi.core.components.staticComponent import (
+    TextComponent,
+    UploadComponent,
+    IconComponent,
+    SvgIconComponent,
+)
 from pybi.core.components.reactiveComponent import (
     ReactiveComponent,
     Slicer,
     Table,
     TextValue,
+    Markdown,
+    Input,
+    NumberSlider,
 )
 from pybi.core.components.containerComponent import (
     ContainerComponent,
@@ -13,4 +21,7 @@ from pybi.core.components.containerComponent import (
     FlowBoxComponent,
     GridBoxComponent,
     TabsComponent,
+    AffixComponent,
 )
+
+from pybi.core.components.mermaid import Mermaid
