@@ -3,6 +3,7 @@ from typing import TYPE_CHECKING, Dict, Union, List, Optional
 
 from .componentTag import ComponentTag
 from .component import Component
+from pybi.icons.iconManager import get_singleton as get_iconManager
 
 if TYPE_CHECKING:
     from pybi.app import App
@@ -176,7 +177,7 @@ class TabsComponent(ContainerComponent):
         if len(names) > len(set(names)):
             raise Exception("names cannot be duplicated")
         self.names = names
-        self.icons = []
+        self.__icons = []
         self.tabsProps = {}
         self.panelsProps = {}
         self.tabsClasses: List[str] = []
@@ -198,7 +199,7 @@ class TabsComponent(ContainerComponent):
         return res
 
     def set_icons(self, icons: List[str]):
-        self.icons = icons
+        self.__icons = icons
 
         self.set_tabsProps({"inline-label": len(icons) > 0})
         return self
@@ -234,11 +235,17 @@ class TabsComponent(ContainerComponent):
         data = super()._to_json_dict()
         data["tabsClasses"] = list(dict.fromkeys(data["tabsClasses"]).keys())
         data["panelsClasses"] = list(dict.fromkeys(data["panelsClasses"]).keys())
-        return data
 
+        icon_ids = []
+        for icon in self.__icons:
+            icon_id = get_iconManager().make_icon(icon)
+            icon_ids.append(icon_id)
+
+        data["iconIds"] = icon_ids
+
+        return data
 
 
 class AffixComponent(ContainerComponent):
     def __init__(self, appHost: Optional[App] = None) -> None:
         super().__init__(ComponentTag.Affix, appHost)
-
