@@ -119,16 +119,17 @@ class EChartInfo(Jsonable):
         datasetInfos: List[EChartDatasetInfo],
         updateInfos: List[EChartUpdateInfo],
         jscodes: List[EChartJscode],
+        mapIds: Optional[List[str]] = None,
     ):
         self.options = options
         self.datasetInfos = datasetInfos
         self.updateInfos = updateInfos
         self.jsCodes = jscodes
+        self.mapIds = mapIds or []
 
 
 class EChart(ReactiveComponent):
     def __init__(self, *, option_type="dict") -> None:
-
         super().__init__(ComponentTag.EChart)
         self._chart_mappings = {}
         self._chartInfos: List[EChartInfo] = []
