@@ -27,9 +27,9 @@ class SvgIconComponent(Component):
 
 
 class IconComponent(Component):
-    def __init__(self, icon: str, size: str, color: str) -> None:
+    def __init__(self, icon_id: str, size: str, color: str) -> None:
         super().__init__(ComponentTag.Icon)
 
-        self.icon = icon
+        self.iconID = icon_id
         self.size = size
         self.color = color
