@@ -1,6 +1,5 @@
 from __future__ import annotations
 
-from pybi.core.sql import SqlInfo
 
 from .base import BaseChart
 import pybi as pbi
@@ -8,8 +7,6 @@ import pybi.utils.sql as sqlUtils
 
 
 from typing import TYPE_CHECKING, Optional
-from pybi.core.components.reactiveComponent import EChartDatasetInfo
-from .utils import merge_user_options
 
 if TYPE_CHECKING:
     from pybi.core.dataSource import DataSourceTable
@@ -106,6 +103,6 @@ class BarChart(BaseChart):
         catAxis["type"] = "category"
         valueAxis["type"] = "value"
 
-        self._update_props_by_path(base_opt)
+        base_opt = self._post_options(base_opt)
 
-        return base_opt, self._updateInfos
+        return base_opt, self._updateInfos, []
