@@ -4,8 +4,6 @@ import pybi as pbi
 import pybi.utils.sql as sqlUtils
 
 from typing import TYPE_CHECKING, Optional
-from pybi.core.components.reactiveComponent import EChartDatasetInfo
-from .utils import merge_user_options
 
 if TYPE_CHECKING:
     from pybi.core.dataSource import DataSourceTable
@@ -81,4 +79,4 @@ class PieChart(BaseChart):
         opts["tooltip"] = {"trigger": "item"}
 
         self._update_props_by_path(base_opt)
-        return base_opt, self._updateInfos
+        return base_opt, self._updateInfos, []
