@@ -3,9 +3,7 @@ from .base import BaseChart
 import pybi as pbi
 
 from typing import TYPE_CHECKING, Optional
-from pybi.core.components.reactiveComponent import EChartDatasetInfo
-from .utils import merge_user_options
-import pybi.utils.sql as sqlUtils
+
 
 if TYPE_CHECKING:
     from pybi.core.dataSource import DataSourceTable
@@ -68,4 +66,4 @@ class ScatterChart(BaseChart):
         opts["tooltip"] = {"trigger": "item"}
 
         self._update_props_by_path(base_opt)
-        return base_opt, self._updateInfos
+        return base_opt, self._updateInfos, []
