@@ -41,3 +41,10 @@ def _iter_name(text: str):
 
     if start_idx <= len(text) - 1:
         yield text[start_idx : len(text)]
+
+def apply_agg(self_agg: str, self_y: str):
+
+    if '${}' in self_agg:
+        return self_agg.replace('${}', self_y)
+    else:
+        return f'{self_agg}(`{self_y}`)'
\ No newline at end of file
